# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .test_suite_run_execution_chat_history_output import TestSuiteRunExecutionChatHistoryOutput
from .test_suite_run_execution_error_output import TestSuiteRunExecutionErrorOutput
from .test_suite_run_execution_function_call_output import TestSuiteRunExecutionFunctionCallOutput
from .test_suite_run_execution_json_output import TestSuiteRunExecutionJsonOutput
from .test_suite_run_execution_number_output import TestSuiteRunExecutionNumberOutput
from .test_suite_run_execution_search_results_output import TestSuiteRunExecutionSearchResultsOutput
from .test_suite_run_execution_string_output import TestSuiteRunExecutionStringOutput


class TestSuiteRunExecutionOutput_String(TestSuiteRunExecutionStringOutput):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecutionOutput_Number(TestSuiteRunExecutionNumberOutput):
    type: typing.Literal["NUMBER"] = "NUMBER"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecutionOutput_Json(TestSuiteRunExecutionJsonOutput):
    type: typing.Literal["JSON"] = "JSON"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecutionOutput_ChatHistory(TestSuiteRunExecutionChatHistoryOutput):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecutionOutput_SearchResults(TestSuiteRunExecutionSearchResultsOutput):
    type: typing.Literal["SEARCH_RESULTS"] = "SEARCH_RESULTS"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecutionOutput_Error(TestSuiteRunExecutionErrorOutput):
    type: typing.Literal["ERROR"] = "ERROR"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecutionOutput_FunctionCall(TestSuiteRunExecutionFunctionCallOutput):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TestSuiteRunExecutionOutput = typing.Union[
    TestSuiteRunExecutionOutput_String,
    TestSuiteRunExecutionOutput_Number,
    TestSuiteRunExecutionOutput_Json,
    TestSuiteRunExecutionOutput_ChatHistory,
    TestSuiteRunExecutionOutput_SearchResults,
    TestSuiteRunExecutionOutput_Error,
    TestSuiteRunExecutionOutput_FunctionCall,
]
