# This file was auto-generated by Fern from our API Definition.

import typing

VellumVariableType = typing.Union[
    typing.Literal[
        "STRING", "NUMBER", "JSON", "CHAT_HISTORY", "SEARCH_RESULTS", "ERROR", "ARRAY", "FUNCTION_CALL", "IMAGE", "NULL"
    ],
    typing.Any,
]
