# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .named_scenario_input_chat_history_variable_value_request import NamedScenarioInputChatHistoryVariableValueRequest
from .named_scenario_input_string_variable_value_request import NamedScenarioInputStringVariableValueRequest


class NamedScenarioInputRequest_String(NamedScenarioInputStringVariableValueRequest):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedScenarioInputRequest_ChatHistory(NamedScenarioInputChatHistoryVariableValueRequest):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


NamedScenarioInputRequest = typing.Union[NamedScenarioInputRequest_String, NamedScenarioInputRequest_ChatHistory]
