# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .test_suite_run_deployment_release_tag_exec_config_request import TestSuiteRunDeploymentReleaseTagExecConfigRequest
from .test_suite_run_external_exec_config_request import TestSuiteRunExternalExecConfigRequest
from .test_suite_run_workflow_release_tag_exec_config_request import TestSuiteRunWorkflowReleaseTagExecConfigRequest


class TestSuiteRunExecConfigRequest_DeploymentReleaseTag(TestSuiteRunDeploymentReleaseTagExecConfigRequest):
    type: typing.Literal["DEPLOYMENT_RELEASE_TAG"] = "DEPLOYMENT_RELEASE_TAG"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecConfigRequest_WorkflowReleaseTag(TestSuiteRunWorkflowReleaseTagExecConfigRequest):
    type: typing.Literal["WORKFLOW_RELEASE_TAG"] = "WORKFLOW_RELEASE_TAG"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecConfigRequest_External(TestSuiteRunExternalExecConfigRequest):
    type: typing.Literal["EXTERNAL"] = "EXTERNAL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TestSuiteRunExecConfigRequest = typing.Union[
    TestSuiteRunExecConfigRequest_DeploymentReleaseTag,
    TestSuiteRunExecConfigRequest_WorkflowReleaseTag,
    TestSuiteRunExecConfigRequest_External,
]
