# This file was auto-generated by Fern from our API Definition.

import typing

VellumErrorCodeEnum = typing.Union[
    typing.Literal["INVALID_REQUEST", "PROVIDER_ERROR", "INTERNAL_SERVER_ERROR", "USER_DEFINED_ERROR"], typing.Any
]
