# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .search_filters_request import SearchFiltersRequest
from .search_result_merging_request import SearchResultMergingRequest
from .search_weights_request import SearchWeightsRequest


class SearchRequestOptionsRequest(pydantic_v1.BaseModel):
    limit: typing.Optional[int] = pydantic_v1.Field(default=None)
    """
    The maximum number of results to return.
    """

    weights: typing.Optional[SearchWeightsRequest] = pydantic_v1.Field(default=None)
    """
    The weights to use for the search. Must add up to 1.0.
    """

    result_merging: typing.Optional[SearchResultMergingRequest] = pydantic_v1.Field(default=None)
    """
    The configuration for merging results.
    """

    filters: typing.Optional[SearchFiltersRequest] = pydantic_v1.Field(default=None)
    """
    The filters to apply to the search.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
